#!/bin/bash
SERVICE_NAME=distribution
DISTRIBUTION_BIN_FOLDER="$(cd $(dirname "${BASH_SOURCE[0]}") && pwd)"
defaultEnv="${DISTRIBUTION_BIN_FOLDER}/distribution.default"

# Support old parameters passed to java command
EXTRA_CONF="$DOCKER_COMPOSE_FLAGS"
EXTRA_CONF="$EXTRA_CONF $DEFAULT_JAVA_OPTS"

[ ! -z "$EXTRA_CONF" ] || export EXTRA_JAVA_OPTS=$EXTRA_CONF

# Map contains environment variable key from old version to key from new version
# This info will be used to assign value from old key to new key
# Note : Allowed values in a environment key are upper case alphabet, number and underscore
DISTRIBUTION_ENV_MAP="""
                        shared.database.host=POSTGRES_HOST
                        shared.database.port=POSTGRES_PORT
                        shared.database.database=POSTGRES_DATABASE
                        shared.database.username=POSTGRES_USERNAME
                        shared.database.password=POSTGRES_PASSWORD
                        shared.security.masterKey=MASTER_KEY
                        ${SERVICE_NAME}.extraJavaOpts=EXTRA_JAVA_OPTS
                    """

errorExit() {
  echo "ERROR: $@"
  exit 1
}

sourceScript(){
    local file=$1

    [ ! -z "${file}" ] || errorExit "target file is not passed to source a file"
    [   -f "${file}" ] || errorExit "${file} file is not found"
    source "${file}"   || errorExit "Unable to source ${file}, please check if the $USER user has permissions to perform this action"
}

initEnv() {
    sourceScript "${defaultEnv}"
    [ ! -z "${JF_PRODUCT_HOME}" ]  || errorExit "Variable JF_PRODUCT_HOME is not set in ${defaultEnv}"
}

initHelpers(){
    local systemYamlHelper="${PRODUCT_BIN_FOLDER}"/systemYamlHelper.sh
    local installerCommon="${PRODUCT_BIN_FOLDER}"/installerCommon.sh
    local distributionCommon="${PRODUCT_BIN_FOLDER}"/distributionCommon.sh
    export YQ_PATH="${PRODUCT_BIN_FOLDER}/../third-party/yq"

    sourceScript "${installerCommon}"
    sourceScript "${distributionCommon}"
    sourceScript "${systemYamlHelper}"
    PRODUCT_NAME=$DISTRIBUTION_LABEL
    export JF_SYSTEM_YAML="${JF_PRODUCT_HOME}/var/etc/system.yaml"
    setupScriptLogsRedirection || true
}

PRODUCT_BIN_FOLDER=${JF_PRODUCT_HOME}/app/bin

initEnv
initHelpers
commonStartupActions "docker" 2>/dev/null
translateEnv "${DISTRIBUTION_ENV_MAP}"
setupNodeDetails

terminate () {
    logger "Terminate signal received, attempting a graceful shutdown"
    kill ${distributionPid}
    if isProcessRunning "${distributionPid}" "${SERVICE_NAME}" "${DIST_SHUTDOWN_WAIT_TIME}" 2>/dev/null; then
      warn "Could not perform a graceful shutdown, trying a hard kill"
      kill -9 ${distributionPid}
    fi
}

DISTRIBUTION_PID_FILE="${JF_PRODUCT_HOME}/app/${SERVICE_NAME}/${SERVICE_NAME}.pid"
DIST_SHUTDOWN_WAIT_TIME=30

trap terminate SIGINT SIGTERM SIGHUP

exec ${JF_PRODUCT_HOME}/app/${SERVICE_NAME}/bin/${SERVICE_NAME}.sh &

distributionPid=$!

if [ -n "${DISTRIBUTION_PID_FILE}" ];
then
    mkdir -p $(dirname "${DISTRIBUTION_PID_FILE}") || \
    errorExit "Could not create parent dir for ${DISTRIBUTION_PID_FILE}";
fi

echo "${distributionPid}" > ${DISTRIBUTION_PID_FILE}

wait ${distributionPid}
